You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openjpa.apache.org by mt...@apache.org on 2009/05/30 15:11:24 UTC

svn commit: r780258 - /openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java

Author: mtylenda
Date: Sat May 30 13:11:24 2009
New Revision: 780258

URL: http://svn.apache.org/viewvc?rev=780258&view=rev
Log:
OPENJPA-847: Enable JDBC 3 way of retrieving generated keys

Modified:
    openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java

Modified: openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java
URL: http://svn.apache.org/viewvc/openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java?rev=780258&r1=780257&r2=780258&view=diff
==============================================================================
--- openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java (original)
+++ openjpa/trunk/openjpa-lib/src/main/java/org/apache/openjpa/lib/jdbc/DelegatingDatabaseMetaData.java Sat May 30 13:11:24 2009
@@ -26,7 +26,7 @@
 import org.apache.openjpa.lib.util.ConcreteClassGenerator;
 
 /**
  * Wrapper around a DatabaseMetadata instance.
  *
  * @author Marc Prud'hommeaux
  */
@@ -722,48 +722,49 @@
         return _metaData.usesLocalFiles();
     }
 
-    // JDBC 3.0 methods(unsupported) follow; these are required to be able to
-    // compile against JDK 1.4
+    // JDBC 3.0 methods follow.
 
     public boolean supportsSavepoints() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsSavepoints();
     }
 
     public boolean supportsNamedParameters() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsNamedParameters();
     }
 
     public boolean supportsMultipleOpenResults() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsMultipleOpenResults();
     }
 
     public boolean supportsGetGeneratedKeys() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsGetGeneratedKeys();
     }
 
-    public ResultSet getSuperTypes(String catalog, String schemaPatter,
+    public ResultSet getSuperTypes(String catalog, String schemaPattern,
         String typeNamePattern) throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getSuperTypes(catalog, schemaPattern, typeNamePattern);
     }
 
-    public ResultSet getSuperTables(String catalog, String schemaPatter,
+    public ResultSet getSuperTables(String catalog, String schemaPattern,
         String tableNamePattern) throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getSuperTables(catalog, schemaPattern,
+            tableNamePattern);
     }
 
-    public ResultSet getAttributes(String catalog, String schemaPatter,
+    public ResultSet getAttributes(String catalog, String schemaPattern,
         String typeNamePattern, String attributeNamePattern)
         throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getAttributes(catalog, schemaPattern, typeNamePattern,
+            attributeNamePattern);
     }
 
     public boolean supportsResultSetHoldability(int holdability)
         throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsResultSetHoldability(holdability);
     }
 
     public int getResultSetHoldability() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getResultSetHoldability();
     }
 
     public int getDatabaseMajorVersion() throws SQLException {
@@ -779,19 +780,19 @@
     }
 
     public int getJDBCMinorVersion() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getJDBCMinorVersion();
     }
 
     public int getSQLStateType() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.getSQLStateType();
     }
 
     public boolean locatorsUpdateCopy() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.locatorsUpdateCopy();
     }
 
     public boolean supportsStatementPooling() throws SQLException {
-        throw new UnsupportedOperationException();
+        return _metaData.supportsStatementPooling();
     }
 
     /**
@@ -26,7 +26,7 @@
 
 /**
- * Wrapper around a DatabaseMetadata instance.
+ * Wrapper around a DatabaseMetaData instance.
  *
  * @author Marc Prud'hommeaux